@@ -19,12 +19,11 @@
 
 import logging
 import os
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_config import cfg
 from oslotest import base as oslo_test
-import six
 import sqlalchemy
 from sqlalchemy import Column, MetaData, Table
 from sqlalchemy.engine import url
@@ -116,10 +115,16 @@ class SQLiteSavepointTest(test_base._DbTestCase):
             ).fetchall()
         )
         trans.rollback()
-        self.assertEqual(
-            0,
-            self.engine.scalar(self.test_table.count())
-        )
+
+        with self.engine.connect() as conn:
+            self.assertEqual(
+                0,
+                conn.scalar(
+                    sqlalchemy.select(
+                        [sqlalchemy.func.count(self.test_table.c.id)],
+                    ).select_from(self.test_table)
+                )
+            )
 
     def test_savepoint_middle(self):
         with self.engine.begin() as conn:
@@ -683,12 +688,8 @@ class CreateEngineTest(oslo_test.BaseTestCase):
         self.assertNotIn('poolclass', self.args)
 
     def _test_mysql_connect_args_default(self, connect_args):
-        if six.PY3:
-            self.assertEqual({'charset': 'utf8', 'use_unicode': 1},
-                             connect_args)
-        else:
-            self.assertEqual({'charset': 'utf8', 'use_unicode': 0},
-                             connect_args)
+        self.assertEqual({'charset': 'utf8', 'use_unicode': 1},
+                         connect_args)
 
     def test_mysql_connect_args_default(self):
         engines._init_connection_args(
